/*
    Copyright (C) 1995-1998 AROS - The Amiga Research OS
    $Id: setfilesystask.c,v 1.1.1.1 2005/03/15 15:54:40 laire Exp $

    Desc: Set the current filesystem handler for a process.
    Lang: english
*/
#include "dos_intern.h"
#include <proto/exec.h>

/*****************************************************************************

    NAME */
#include <dos/dosextens.h>
#include <proto/dos.h>

	AROS_LH1(struct MsgPort *, SetFileSysTask,

/*  SYNOPSIS */
	AROS_LHA(struct MsgPort *, task, D1),

/*  LOCATION */
	struct DosLibrary *, DOSBase, 88, Dos)

/*  FUNCTION
	Set the default filesystem handler for the current process,
	the old filesystem handler will be returned.

    INPUTS
	task		- The new filesystem handler.

    RESULT
	The old filesystem handler.

    NOTES

    EXAMPLE

    BUGS

    SEE ALSO
	GetFileSysTask()

    INTERNALS

    HISTORY
	27-11-96    digulla automatically created from
			    dos_lib.fd and clib/dos_protos.h

*****************************************************************************/
{
    AROS_LIBFUNC_INIT
    AROS_LIBBASE_EXT_DECL(struct DosLibrary *,DOSBase)

    struct Process *me = (struct Process *)FindTask(NULL);
    APTR old;

    DEBUG_ACCESSOR(dprintf("SetFileSystemTask: me = $%lx, new = $%lx, old = $%lx\n",
			   (ULONG) me, (ULONG) task, me->pr_Task.tc_Node.ln_Type == NT_PROCESS ? (ULONG) me->pr_FileSystemTask : 0));

    FAILFORTASK(me, return NULL;)

    old = me->pr_FileSystemTask;
    me->pr_FileSystemTask = task;
    return old;

    AROS_LIBFUNC_EXIT
} /* SetFileSysTask */
